<template

>
  <a-card :bordered="false" title="">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="工艺参数模版编码">
              <j-input placeholder="请输入工艺参数模版编码" v-model="queryParam.num"></j-input>
            </a-form-item>
          </a-col>
          <template>
            <a-col :xl="6" :lg="7" :md="8" :sm="24">
              <a-form-item label="工艺参数模版名称">
                <j-input placeholder="请输入工艺参数模版名称" v-model="queryParam.name"></j-input>
              </a-form-item>
            </a-col>
          </template>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <span style="float: left; overflow: hidden" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="primary" @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择
        <a style="font-weight: 600">{{ selectedRowKeys.length }}</a
        >项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        class="j-table-force-nowrap"
        :scroll="{ x: true }"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{ selectedRowKeys: selectedRowKeys, onChange: onSelectChange }"
        :customRow="clickThenSelect"
        @change="handleTableChange"
      >
        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>
      </a-table>
    </div>

    <a-tabs defaultActiveKey="1">
      <a-tab-pane tab="工艺参数明细" key="1">
        <ProcessParametersTemplateDetail :processParametersTemplateId="processParametersTemplateId" />
      </a-tab-pane>
    </a-tabs>

    <process-parameters-template-model ref="modalForm" @ok="modalFormOk"></process-parameters-template-model>
  </a-card>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import ProcessParametersTemplateModel from './modules/processParametersTemplate/ProcessParametersTemplateModel'
import { getAction } from '@/api/manage'
import ProcessParametersTemplateDetail from './ProcessParametersTemplateDetail'
import '@/assets/less/TableExpand.less'

export default {
  name: 'ProcessParametersTemplateList',
  mixins: [JeecgListMixin],
  components: {
    ProcessParametersTemplateDetail,
    ProcessParametersTemplateModel,
  },
  data() {
    return {
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
        },
        {
          title: '工艺参数模板编码',
          align: 'center',
          dataIndex: 'num',
          width: 150,
        },
        {
          title: '工艺参数模板名称',
          align: 'center',
          dataIndex: 'name',
          width: 150,
        },
        {
          title: '创建人',
          align: 'center',
          dataIndex: 'createBy',
          width: 150,
        },
        {
          title: '创建日期',
          align: 'center',
          dataIndex: 'createTime',
          width: 150,
        },
        {
          title: '更新人',
          align: 'center',
          dataIndex: 'updateBy',
          width: 150,
        },
        {
          title: '更新日期',
          align: 'center',
          dataIndex: 'updateTime',
          width: 150,
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark',
          ellipsis: true,
          width: 200,
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          width: 150,
          scopedSlots: { customRender: 'action' },
        },
      ],
      url: {
        list: '/eam/processParametersTemplate/list',
        delete: '/eam/processParametersTemplate/delete',
        deleteBatch: '/eam/processParametersTemplate/deleteBatch',
      },
      dictOptions: {},
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '50'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0,
      },
      selectedTemplateId: '',
      superFieldList: [],
      processParametersTemplateId: '',
    }
  },
  created() {
    this.getSuperFieldList()
  },
  computed: {},
  methods: {
    initDictConfig() {},
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          },
        },
      }
    },
    onClearSelected() {
      this.selectedRowKeys = []
      this.selectionRows = []
      this.selectedTemplateId = ''
    },
    onSelectChange(selectedRowKeys, selectionRows) {
      if (selectedRowKeys.length == 1) {
        this.selectedTemplateId = selectedRowKeys[0]
        this.processParametersTemplateId = selectionRows[0]['id']
      } else {
        this.selectedTemplateId = ''
        this.processParametersTemplateId = ''
      }
      this.selectedRowKeys = selectedRowKeys
      this.selectionRows = selectionRows
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      this.onClearSelected()
      var params = this.getQueryParams() //查询条件
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })
    },
    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'string', value: 'code', text: '编码', dictCode: '' })
      fieldList.push({ type: 'string', value: 'name', text: '名称', dictCode: '' })
      fieldList.push({ type: 'string', value: 'remark', text: '备注', dictCode: '' })
      fieldList.push({ type: 'string', value: 'createBy', text: '创建人', dictCode: '' })
      fieldList.push({ type: 'date', value: 'createTime', text: '创建时间' })
      fieldList.push({ type: 'string', value: 'updateBy', text: '更新人', dictCode: '' })
      fieldList.push({ type: 'date', value: 'updateTime', text: '更新时间' })
      this.superFieldList = fieldList
    },
    searchReset() {
      this.queryParam = {}
      this.processParametersTemplateId = ''
      this.loadData(1)
    },
  },
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>